@@ -3,12 +3,13 @@
 from tkinter import *
 import os
 veri = Tk()
-veri.title('KYAK2-Void-d')
+veri.title('KYAK2-Void')
 veri.geometry('80x230')
 veri.configure(bg='#252726')
 veri.maxsize(80,230)
 veri.minsize(80,230)
 
+
 def deger1():
     os.system("loginctl suspend")
     os.system("xscreensaver-command -l")
